﻿namespace GlobalCommandsModule
{
    using Microsoft.Practices.Composite.Events;
    using Microsoft.Practices.Composite.Modularity;
    using Microsoft.Practices.Composite.Regions;
    using Microsoft.Practices.Unity;

    /// <summary>
    /// Displays the company's logo.
    /// </summary>
    [Module(ModuleName = "GlobalCommandsModule")]
    public class GlobalCommandsModule : IModule
    {
        /// <summary>
        /// CAL Region Manager.
        /// </summary>
        private readonly IRegionManager regionManager;

        /// <summary>
        /// CAL Unity Container.
        /// </summary>
        private readonly IUnityContainer container;

        /// <summary>
        /// CAL Event Aggregator.
        /// </summary>
        private readonly IEventAggregator eventAggregator;

        /// <summary>
        /// Initializes a new instance of the GlobalCommandsModule class.
        /// </summary>
        /// <param name="container">The injectred CAL container.</param>
        /// <param name="regionManager">The injected CAL region manager.</param>
        /// <param name="eventAggregator">The injected CAL event aggregator.</param>
        public GlobalCommandsModule(
            IUnityContainer container,
            IRegionManager regionManager,
            IEventAggregator eventAggregator)
        {
            this.container = container;
            this.regionManager = regionManager;
            this.eventAggregator = eventAggregator;
        }

        /// <summary>
        /// The module's "Main" method, to be called by CAL.
        /// </summary>
        public void Initialize()
        {
            this.RegisterViewsAndServices();

            Views.SelectionCommandView commands =
                this.container.Resolve<Views.SelectionCommandView>();
            this.regionManager.Regions["CommandsRegion"].Add(commands);
        }

        /// <summary>
        /// Register views or services to CAL.
        /// </summary>
        public void RegisterViewsAndServices()
        {
            this.container.RegisterType<Views.SelectionCommandView>(
                new ContainerControlledLifetimeManager());
        }
    }
}
