﻿namespace SelectionModule
{
    using Microsoft.Practices.Composite.Events;
    using Microsoft.Practices.Composite.Modularity;
    using Microsoft.Practices.Composite.Regions;
    using Microsoft.Practices.Unity;

    /// <summary>
    /// Displays the company's logo.
    /// </summary>
    [Module(ModuleName = "SelectionModule")]
    public class SelectionModule : IModule
    {
        /// <summary>
        /// CAL Region Manager.
        /// </summary>
        private readonly IRegionManager regionManager;

        /// <summary>
        /// CAL Unity Container.
        /// </summary>
        private readonly IUnityContainer container;

        /// <summary>
        /// CAL Event Aggregator.
        /// </summary>
        private readonly IEventAggregator eventAggregator;

        /// <summary>
        /// Initializes a new instance of the SelectionModule class.
        /// </summary>
        /// <param name="container">The injected CAL container.</param>
        /// <param name="regionManager">The injected CAL region manager.</param>
        /// <param name="eventAggregator">The injected CAL event aggregator.</param>
        public SelectionModule(
            IUnityContainer container,
            IRegionManager regionManager,
            IEventAggregator eventAggregator)
        {
            this.container = container;
            this.regionManager = regionManager;
            this.eventAggregator = eventAggregator;
        }

        /// <summary>
        /// The module's "Main" method, to be called by CAL.
        /// </summary>
        public void Initialize()
        {
            this.RegisterViewsAndServices();

            Views.SelectionView view =
                this.container.Resolve<Views.SelectionView>();
            IRegion mainRegion = this.regionManager.Regions["MainRegion"];
            mainRegion.Add(view);
        }

        /// <summary>
        /// Register views or services to CAL.
        /// </summary>
        public void RegisterViewsAndServices()
        {
            this.container.RegisterType<Views.SelectionView>(
                new ContainerControlledLifetimeManager());
        }
    }
}
