﻿namespace StatusModule
{
    using Microsoft.Practices.Composite.Events;
    using Microsoft.Practices.Composite.Modularity;
    using Microsoft.Practices.Composite.Regions;
    using Microsoft.Practices.Unity;

    /// <summary>
    /// Displays the company's logo.
    /// </summary>
    [Module(ModuleName = "Status Module")]
    public class StatusModule : IModule
    {
        /// <summary>
        /// CAL region manager.
        /// </summary>
        private readonly IRegionManager regionManager;

        /// <summary>
        /// CAL Unity container.
        /// </summary>
        private readonly IUnityContainer container;

        /// <summary>
        /// CAL event aggregator.
        /// </summary>
        private readonly IEventAggregator eventAggregator;

        /// <summary>
        /// Initializes a new instance of the StatusModule class.
        /// </summary>
        /// <param name="container">The injected CAL container.</param>
        /// <param name="regionManager">The injected CAL region manager.</param>
        /// <param name="eventAggregator">The injected CAL event aggregator.</param>
        public StatusModule(
            IUnityContainer container,
            IRegionManager regionManager,
            IEventAggregator eventAggregator)
        {
            this.container = container;
            this.regionManager = regionManager;
            this.eventAggregator = eventAggregator;
        }

        /// <summary>
        /// The module's "Main" method, to be called by CAL.
        /// </summary>
        public void Initialize()
        {
            this.RegisterViewsAndServices();

            PresentationModels.IStatusPresentationModel model =
                this.container.Resolve<PresentationModels.StatusPresentationModel>();
            IRegion statusRegion = this.regionManager.Regions["StatusRegion"];
            statusRegion.Add(model.View);
        }

        /// <summary>
        /// Register views or services to CAL.
        /// </summary>
        public void RegisterViewsAndServices()
        {
            this.container.RegisterType<Views.IStatusView, Views.StatusView>(
                new ContainerControlledLifetimeManager());
            this.container.RegisterType<PresentationModels.IStatusPresentationModel, PresentationModels.StatusPresentationModel>(
                new ContainerControlledLifetimeManager());
        }
    }
}
